==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Enviar");
define("_FYOURNAME","Seu Nome:");
define("_FYOUREMAIL","Seu E-mail:");
define("_FFRIENDNAME","Nome do Seu Amigo:");
define("_FFRIENDEMAIL","E-Mail do Seu Amigo:");
define("_HELLO","Al");
define("_YOURFRIEND","Seu Amigo");
define("_RECOMMEND","Indique este site a um amigo");
define("_INTSITE","Participe do Site:");
define("_OURSITE","considerando-o como o seu site");
define("_INTSENT","participando ativamente do mesmo.");
define("_FSITENAME","Nome do Site:");
define("_FSITEURL","Endereo do Site:");
define("_FREFERENCE","Suas referncias sobre o nosso site foi enviada para");
define("_THANKSREC","Obrigado por indicar o nosso site!");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Enviar");
define("_FYOURNAME","Seu Nome:");
define("_FYOUREMAIL","Seu E-mail:");
define("_FFRIENDNAME","Nome do Seu Amigo:");
define("_FFRIENDEMAIL","E-Mail do Seu Amigo:");
define("_HELLO","Al");
define("_YOURFRIEND","Seu Amigo");
define("_RECOMMEND","Indique este site a um amigo");
define("_INTSITE","Participe do Site:");
define("_OURSITE","considerando-o como o seu site");
define("_INTSENT","participando ativamente do mesmo.");
define("_FSITENAME","Nome do Site:");
define("_FSITEURL","Endereo do Site:");
define("_FREFERENCE","Suas referncias sobre o nosso site foi enviada para");
define("_THANKSREC","Obrigado por indicar o nosso site!");

?>
